@@ -5,7 +5,7 @@
  * license (see LICENSE, in pngcrush.c).
  */
 
-/* Special defines for pngcrush version 1.7.86 */
+/* Special defines for pngcrush version 1.7.87 */
 
 #ifndef PNGCRUSH_H
 #define PNGCRUSH_H
@@ -17,6 +17,7 @@
 /* #undef PNG_FIXED_POINT_SUPPORTED */
 #undef PNG_INCH_CONVERSIONS_SUPPORTED
 #undef PNG_INFO_IMAGE_SUPPORTED
+#undef PNG_READ_PNG_SUPPORTED
 #undef PNG_IO_STATE_SUPPORTED
 #undef PNG_PROGRESSIVE_READ_SUPPORTED
 #undef PNG_READ_ALPHA_MODE_SUPPORTED
@@ -33,6 +34,7 @@
 #undef PNG_READ_USER_CHUNKS_SUPPORTED
 #undef PNG_USER_CHUNKS_SUPPORTED
 #undef PNG_TIME_RFC1123_SUPPORTED
+#undef PNG_WRITE_PNG_SUPPORTED
 #undef PNG_WRITE_BGR_SUPPORTED
 #undef PNG_WRITE_GET_PALETTE_MAX_SUPPORTED
 #undef PNG_WRITE_INVERT_ALPHA_SUPPORTED
